# AIBrix

[AIBrix](https://github.com/vllm-project/aibrix) is a cloud-native control plane that integrates with vLLM to simplify Kubernetes deployment, scaling, routing, and LoRA adapter management for large language model inference.

For installation and usage instructions, please refer to the [AIBrix documentation](https://aibrix.readthedocs.io/).
